import { useMachine } from '@xstate/react';
import { LoggerController } from '../controllers/LoggerController';
import type {
  ExtractionLog,
  LoggerContext,
  TransmissionLog,
} from '../types/LoggerTypes';

type LoggerProps = Partial<LoggerContext> &
  Omit<LoggerContext, 'timestamp' | 'content' | 'deviceInfo' | 'userID'>;

export const useRookLogger = () => {
  const [_, send] = useMachine(LoggerController);

  const initLogger = (props: LoggerProps): void => {
    const { clientUUID, environment, sdkInfo, userID } = props;

    send({
      type: 'init',
      payload: {
        clientUUID,
        environment,
        sdkInfo,
        userID,
      },
    });
  };

  const sendExtractionLog = (content: ExtractionLog): void => {
    send({ type: 'send', payload: content });
  };

  const sendTransmissionLog = (content: TransmissionLog): void => {
    send({ type: 'send', payload: content });
  };

  return {
    initLogger,
    sendExtractionLog,
    sendTransmissionLog,
  };
};
